#define DELIMITER_MASK     0xffff
#define EG_RECORD_HWM      16000
#define EG_RECORD_COUNT    16384
#define EG_ADDR_SIZE       0x4000

extern struct group_data groups[NOS_EG_GROUPS];
extern short *addr2adc[EG_ADDR_SIZE];
extern short adc2addr[NOS_ADC_WORDS];

#if NeedFunctionPrototype
int rdtape_eg(int, int);
void eg_filt_tail(short *, short *);
short *eg_filt_head(short *);
int write_eg(int, short *, int);
#else
int rdtape_eg();
void eg_filt_tail();
short *eg_filt_head();
int write_eg();
#endif

